@@ -1,6 +1,6 @@
 package Git::More;
 {
-  $Git::More::VERSION = '0.034';
+  $Git::More::VERSION = '0.035';
 }
 # ABSTRACT: A Git extension with some goodies for hook developers.
 
@@ -288,6 +288,11 @@ sub get_affected_ref_commits {
     return @{$affected->{$ref}{commits}};
 }
 
+sub set_authenticated_user {
+    my ($git, $user) = @_;
+    return $git->{more}{authenticated_user} = $user;
+}
+
 sub authenticated_user {
     my ($git) = @_;
 
@@ -333,7 +338,7 @@ Git::More - A Git extension with some goodies for hook developers.
 
 =head1 VERSION
 
-version 0.034
+version 0.035
 
 =head1 SYNOPSIS
 
@@ -549,6 +554,13 @@ the Git action. It groks it from the C<githooks.userenv> configuration
 variable specification, which is described in the C<Git::Hooks>
 documentation. It's useful for most access control check plugins.
 
+=head2 set_authenticated_user USERNAME
+
+This method can be used to set the username of the authenticated user
+when the default heristics defined above aren't enough. The name will
+be cached so that subsequent invokations of B<authenticated_user> will
+return this.
+
 =head2 get_current_branch
 
 This method returns the repository's current branch name, as indicated
